@@ -6,7 +6,7 @@
  * Date        : 2011-02-09
  * Description : color label filter
  *
- * Copyright (C) 2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,7 +44,7 @@ class ColorLabelFilter : public ColorLabelWidget
 
 public:
 
-    ColorLabelFilter(QWidget* parent=0);
+    explicit ColorLabelFilter(QWidget* const parent=0);
     ~ColorLabelFilter();
 
     QList<TAlbum*> getCheckedColorLabelTags();
