@@ -7,9 +7,9 @@
  * Description : Qt item view for images
  *
  * Copyright (C) 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2011 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2013 by Michael G. Hansen <mike at mghansen dot de>
+ * Copyright (C) 2009-2014 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011      by Andi Clemens <andi dot clemens at gmail dot com>
+ * Copyright (C) 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -66,12 +66,12 @@
 #include "digikamimagefacedelegate.h"
 #include "dio.h"
 #include "facerejectionoverlay.h"
-#include "faceiface.h"
 #include "groupindicatoroverlay.h"
 #include "imagealbumfiltermodel.h"
 #include "imagealbummodel.h"
 #include "imagedragdrop.h"
 #include "imageratingoverlay.h"
+#include "imagecoordinatesoverlay.h"
 #include "tagslineeditoverlay.h"
 #include "imageviewutilities.h"
 #include "imagewindow.h"
@@ -84,7 +84,7 @@
 namespace Digikam
 {
 
-DigikamImageView::DigikamImageView(QWidget* parent)
+DigikamImageView::DigikamImageView(QWidget* const parent)
     : ImageCategorizedView(parent), d(new DigikamImageViewPriv(this))
 {
     installDefaultModels();
@@ -101,7 +101,7 @@ DigikamImageView::DigikamImageView(QWidget* parent)
     setItemDelegate(d->normalDelegate);
     setSpacing(10);
 
-    AlbumSettings* settings = AlbumSettings::instance();
+    AlbumSettings* const settings = AlbumSettings::instance();
 
     imageFilterModel()->setCategorizationMode(ImageSortSettings::CategoryByAlbum);
 
@@ -129,16 +129,18 @@ DigikamImageView::DigikamImageView(QWidget* parent)
     d->updateOverlays();
 
     // rating overlay
-    ImageRatingOverlay* ratingOverlay = new ImageRatingOverlay(this);
+    ImageRatingOverlay* const ratingOverlay = new ImageRatingOverlay(this);
     addOverlay(ratingOverlay);
 
     // face overlays
     addRejectionOverlay(d->faceDelegate);
     addAssignNameOverlay(d->faceDelegate);
 
-    GroupIndicatorOverlay* groupOverlay = new GroupIndicatorOverlay(this);
+    GroupIndicatorOverlay* const groupOverlay = new GroupIndicatorOverlay(this);
     addOverlay(groupOverlay);
 
+    addOverlay(new ImageCoordinatesOverlay(this));
+
     connect(ratingOverlay, SIGNAL(ratingEdited(QList<QModelIndex>,int)),
             this, SLOT(assignRating(QList<QModelIndex>,int)));
 
@@ -257,9 +259,13 @@ void DigikamImageView::confirmFaces(const QList<QModelIndex>& indexes, int tagId
     QList<QModelIndex> sourceIndexes;
 
     // fast-remove in the "unknown person" view
-    const bool needFastRemove = d->faceMode
-                                && imageAlbumModel()->currentAlbum()
-                                && tagId != imageAlbumModel()->currentAlbum()->id();
+
+    bool needFastRemove = false;
+    if(imageAlbumModel()->currentAlbums().size() == 1)
+    {
+        needFastRemove = d->faceMode
+                         && (tagId != imageAlbumModel()->currentAlbums().first()->id());
+    }
 
     foreach(const QModelIndex& index, indexes)
     {
@@ -321,6 +327,7 @@ void DigikamImageView::showContextMenuOnInfo(QContextMenuEvent* event, const Ima
 {
     QList<ImageInfo> selectedInfos = selectedImageInfosCurrentFirst();
     QList<qlonglong> selectedImageIDs;
+
     foreach(const ImageInfo& info, selectedInfos)
     {
         selectedImageIDs << info.id();
@@ -328,7 +335,7 @@ void DigikamImageView::showContextMenuOnInfo(QContextMenuEvent* event, const Ima
 
     // Temporary actions --------------------------------------
 
-    QAction* viewAction = new QAction(SmallIcon("viewimage"), i18nc("View the selected image", "Preview"), this);
+    QAction* const viewAction = new QAction(SmallIcon("viewimage"), i18nc("View the selected image", "Preview"), this);
     viewAction->setEnabled(selectedImageIDs.count() == 1);
 
     // --------------------------------------------------------
@@ -367,6 +374,7 @@ void DigikamImageView::showContextMenuOnInfo(QContextMenuEvent* event, const Ima
     cmhelper.addSeparator();
     // --------------------------------------------------------
     cmhelper.addLabelsAction();
+
     if (!d->faceMode)
     {
         cmhelper.addGroupMenu(selectedImageIDs);
@@ -421,7 +429,7 @@ void DigikamImageView::showContextMenuOnInfo(QContextMenuEvent* event, const Ima
 
     // --------------------------------------------------------
 
-    QAction* choice = cmhelper.exec(event->globalPos());
+    QAction* const choice = cmhelper.exec(event->globalPos());
 
     if (choice && (choice == viewAction))
     {
@@ -434,6 +442,7 @@ void DigikamImageView::showGroupContextMenu(const QModelIndex& index, QContextMe
     Q_UNUSED(index);
     QList<ImageInfo> selectedInfos = selectedImageInfosCurrentFirst();
     QList<qlonglong> selectedImageIDs;
+
     foreach(const ImageInfo& info, selectedInfos)
     {
         selectedImageIDs << info.id();
@@ -465,7 +474,7 @@ void DigikamImageView::showGroupContextMenu(const QModelIndex& index, QContextMe
 
 void DigikamImageView::showContextMenu(QContextMenuEvent* event)
 {
-    Album* album = currentAlbum();
+    Album* const album = currentAlbum();
 
     if (!album ||
         album->isRoot() ||
@@ -535,7 +544,7 @@ void DigikamImageView::deleteSelected(const ImageViewUtilities::DeleteMode delet
 void DigikamImageView::deleteSelectedDirectly(const ImageViewUtilities::DeleteMode deleteMode)
 {
     ImageInfoList imageInfoList = selectedImageInfos();
-    
+
     d->utilities->deleteImagesDirectly(imageInfoList, deleteMode);
     awayFromSelection();
 }
@@ -666,7 +675,7 @@ void DigikamImageView::slotInitProgressIndicator()
 {
     if (!ProgressManager::instance()->findItembyId("FaceActionProgress"))
     {
-        FileActionProgress* item = new FileActionProgress("FaceActionProgress");
+        FileActionProgress* const item = new FileActionProgress("FaceActionProgress");
 
         connect(&d->editPipeline, SIGNAL(started(QString)),
                 item, SLOT(slotProgressStatus(QString)));
