@@ -145,18 +145,20 @@ private:
     void    showThumbBar(bool visible);
     void    showSideBars(bool visible);
     bool    thumbbarVisibility() const;
+    void    customizedFullScreenMode(bool set);
+    void    toogleShowBar();
 
 private Q_SLOTS:
 
     void slotAlbumSelected(bool val);
     void slotTagSelected(bool val);
-    void slotImageSelected(const ImageInfoList&, bool, bool, const ImageInfoList&);
+    void slotImageSelected(const ImageInfoList&, const ImageInfoList&);
     void slotSelectionChanged(int selectionCount);
     void slotExit();
     void slotShowTip();
     void slotShowKipiHelp();
-    void slotComponentsInfo();
     void slotDBStat();
+    void slotComponentsInfo();
 
     void slotRecurseAlbums(bool);
     void slotRecurseTags(bool);
