@@ -3,8 +3,8 @@
  * Date        : 2008-02-10
  * Description : a plugin to fix automatically camera lens aberrations
  *
- * Copyright (C) 2008 by Adrian Schroeter <adrian at suse dot de>
- * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008      by Adrian Schroeter <adrian at suse dot de>
+ * Copyright (C) 2008-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -59,11 +59,11 @@
 namespace DigikamEnhanceImagePlugin
 {
 
-class LensAutoFixTool::LensAutoFixToolPriv
+class LensAutoFixTool::Private
 {
 public:
 
-    LensAutoFixToolPriv() :
+    Private() :
         configGroupName("Lens Auto-Correction Tool"),
         configShowGrid("Show Grid"),
         maskPreviewLabel(0),
@@ -88,33 +88,33 @@ public:
     EditorToolSettings*    gboxSettings;
 };
 
-LensAutoFixTool::LensAutoFixTool(QObject* parent)
+LensAutoFixTool::LensAutoFixTool(QObject* const parent)
     : EditorToolThreaded(parent),
-      d(new LensAutoFixToolPriv)
+      d(new Private)
 {
     setObjectName("lensautocorrection");
     setToolName(i18n("Lens Auto-Correction"));
     setToolIcon(SmallIcon("lensautofix"));
 
-    d->previewWidget  = new ImageGuideWidget(0, true, ImageGuideWidget::HVGuideMode);
+    d->previewWidget = new ImageGuideWidget(0, true, ImageGuideWidget::HVGuideMode);
     setToolView(d->previewWidget);
     setPreviewModeMask(PreviewToolBar::AllPreviewModes);
 
     // -------------------------------------------------------------
 
-    d->gboxSettings   = new EditorToolSettings;
-    QGridLayout* grid = new QGridLayout(d->gboxSettings->plainPage());
+    d->gboxSettings         = new EditorToolSettings;
+    QGridLayout* const grid = new QGridLayout(d->gboxSettings->plainPage());
 
-    d->showGrid       = new QCheckBox(i18n("Show grid"), d->gboxSettings->plainPage());
+    d->showGrid             = new QCheckBox(i18n("Show grid"), d->gboxSettings->plainPage());
     d->showGrid->setWhatsThis(i18n("Set this option to visualize the correction grid to be applied."));
 
     // -------------------------------------------------------------
 
-    d->cameraSelector = new LensFunCameraSelector(d->gboxSettings->plainPage());
-    DImg* img = d->previewWidget->imageIface()->getOriginalImg();
+    d->cameraSelector      = new LensFunCameraSelector(d->gboxSettings->plainPage());
+    DImg* const img        = d->previewWidget->imageIface()->original();
     DMetadata meta(img->getMetadata());
     d->cameraSelector->setMetadata(meta);
-    KSeparator* line  = new KSeparator(Qt::Horizontal, d->gboxSettings->plainPage());
+    KSeparator* const line = new KSeparator(Qt::Horizontal, d->gboxSettings->plainPage());
 
     // -------------------------------------------------------------
 
@@ -142,8 +142,6 @@ LensAutoFixTool::LensAutoFixTool(QObject* parent)
 
     connect(d->showGrid, SIGNAL(toggled(bool)),
             this, SLOT(slotTimer()));
-
-    init();
 }
 
 LensAutoFixTool::~LensAutoFixTool()
@@ -193,13 +191,13 @@ void LensAutoFixTool::slotResetSettings()
     d->gboxSettings->blockSignals(false);
 }
 
-void LensAutoFixTool::prepareEffect()
+void LensAutoFixTool::preparePreview()
 {
     // Settings information must be get before to disable settings view.
     LensFunContainer settings = d->cameraSelector->settings();
     d->settingsView->assignFilterSettings(settings);
-    ImageIface* iface         = d->previewWidget->imageIface();
-    DImg preview              = iface->getPreviewImg();
+    ImageIface* const iface   = d->previewWidget->imageIface();
+    DImg preview              = iface->preview();
 
     if (d->showGrid->isChecked())
     {
@@ -219,7 +217,7 @@ void LensAutoFixTool::prepareEffect()
         p2.end();
         DImg grid(pix.toImage());
 
-        DColorComposer* composer                  = DColorComposer::getComposer(DColorComposer::PorterDuffNone);
+        DColorComposer* const composer            = DColorComposer::getComposer(DColorComposer::PorterDuffNone);
         DColorComposer::MultiplicationFlags flags = DColorComposer::NoMultiplication;
 
         // Do alpha blending of template on dest image
@@ -234,24 +232,31 @@ void LensAutoFixTool::prepareFinal()
     // Settings information must be handle before to disable settings view.
     LensFunContainer settings = d->cameraSelector->settings();
     d->settingsView->assignFilterSettings(settings);
-    ImageIface iface(0, 0);
-    setFilter(new LensFunFilter(iface.getOriginalImg(), this, settings));
+    ImageIface iface;
+    setFilter(new LensFunFilter(iface.original(), this, settings));
 }
 
-void LensAutoFixTool::putPreviewData()
+void LensAutoFixTool::setPreviewImage()
 {
-    d->previewWidget->imageIface()->putPreviewImage(filter()->getTargetImage().bits());
+    d->previewWidget->imageIface()->setPreview(filter()->getTargetImage());
     d->previewWidget->updatePreview();
 }
 
-void LensAutoFixTool::putFinalData()
+void LensAutoFixTool::setFinalImage()
 {
-    ImageIface iface(0, 0);
-    iface.putOriginalImage(i18n("Lens Auto-Correction"), filter()->filterAction(), filter()->getTargetImage().bits());
-    Digikam::KExiv2Data data = iface.getOriginalMetadata();
+    ImageIface iface;
+    iface.setOriginal(i18n("Lens Auto-Correction"), filter()->filterAction(), filter()->getTargetImage());
+
+    // We need digiKam namespace here, else ambigous compilation failure will happen against KExiv2 namespace.
+    Digikam::KExiv2Data data  = iface.originalMetadata();
+
     // Note: there are certain situations in the editor where these metadata changes may be undone.
     // Ignore for now, as they are not critical.
-    dynamic_cast<LensFunFilter*>(filter())->registerSettingsToXmp(data);
+    LensFunFilter* const fltr = dynamic_cast<LensFunFilter*>(filter());
+
+    if (fltr)
+        fltr->registerSettingsToXmp(data);
+
     iface.setOriginalMetadata(data);
 }
 
