@@ -7,7 +7,7 @@
  * Description : Loader for thumbnails
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2003-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2014 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -77,6 +77,7 @@
 #include "tagregion.h"
 #include "thumbnaildatabaseaccess.h"
 #include "thumbnaildb.h"
+#include "thumbnailsize.h"
 
 using namespace KDcrawIface;
 
@@ -121,14 +122,14 @@ void ThumbnailCreator::initialize()
 int ThumbnailCreator::Private::storageSize() const
 {
     // on-disk thumbnail sizes according to freedesktop spec
-    // always 256 for thumbnail db
+    // for thumbnail db it's always max size
     if (onlyLargeThumbnails)
     {
-        return 256;
+        return ThumbnailSize::maxThumbsSize();
     }
     else
     {
-        return (thumbnailSize <= 128) ? 128 : 256;
+        return (thumbnailSize <= ThumbnailSize::Medium) ? ThumbnailSize::Medium : ThumbnailSize::Huge;
     }
 }
 
@@ -300,7 +301,8 @@ QImage ThumbnailCreator::load(const QString& path, const QRect& rect, bool prege
     if (d->thumbnailStorage == ThumbnailDatabase)
     {
         // image is stored, or created, unrotated, and is now rotated for display
-        if (d->exifRotate)
+        // detail thumbnails are stored readily rotated
+        if (d->exifRotate && rect.isNull())
         {
             image.qimage = exifRotate(image.qimage, image.exifOrientation);
         }
@@ -309,10 +311,8 @@ QImage ThumbnailCreator::load(const QString& path, const QRect& rect, bool prege
     return image.qimage;
 }
 
-QImage ThumbnailCreator::scaleForStorage(const QImage& qimage, bool isFace) const
+QImage ThumbnailCreator::scaleForStorage(const QImage& qimage) const
 {
-    Q_UNUSED(isFace)
-
     if (qimage.width() > d->storageSize() || qimage.height() > d->storageSize())
     {
         /*
@@ -365,19 +365,19 @@ void ThumbnailCreator::store(const QString& path, const QImage& i) const
     store(path, i, QRect());
 }
 
-void ThumbnailCreator::storeDetailThumbnail(const QString& path, const QRect& detailRect, const QImage& i, bool isFace) const
+void ThumbnailCreator::storeDetailThumbnail(const QString& path, const QRect& detailRect, const QImage& i) const
 {
-    store(path, i, detailRect, isFace);
+    store(path, i, detailRect);
 }
 
-void ThumbnailCreator::store(const QString& path, const QImage& i, const QRect& rect, bool isFace) const
+void ThumbnailCreator::store(const QString& path, const QImage& i, const QRect& rect) const
 {
     if (i.isNull())
     {
         return;
     }
 
-    QImage         qimage = scaleForStorage(i, isFace);
+    QImage         qimage = scaleForStorage(i);
     ThumbnailInfo  info   = makeThumbnailInfo(path, rect);
     ThumbnailImage image;
     image.qimage          = qimage;
@@ -427,7 +427,7 @@ void ThumbnailCreator::deleteThumbnailsFromDisk(const QString& filePath) const
 
 // --------------- Thumbnail generation and image handling -----------------------
 
-ThumbnailImage ThumbnailCreator::createThumbnail(const ThumbnailInfo& info, const QRect& detailRect, bool isFace) const
+ThumbnailImage ThumbnailCreator::createThumbnail(const ThumbnailInfo& info, const QRect& detailRect) const
 {
     const QString path = info.filePath;
 
@@ -456,84 +456,86 @@ ThumbnailImage ThumbnailCreator::createThumbnail(const ThumbnailInfo& info, cons
         qimage = loadImageDetail(info, metadata, detailRect, &profile);
         fromDetail = !qimage.isNull();
     }
-
-    if (qimage.isNull())
+    else
     {
-        // Try to extract Exif/IPTC preview first.
-        qimage = loadImagePreview(metadata);
-    }
-
-    QFileInfo fileInfo(path);
-    // To speed-up thumb extraction, we now try to load the images by the file extension.
-    QString ext = fileInfo.suffix().toUpper();
-
-    if (qimage.isNull() && !ext.isEmpty())
-    {
-        if (ext == QString("JPEG") || ext == QString("JPG") || ext == QString("JPE"))
+        if (qimage.isNull())
         {
-            if (colorManage)
-            {
-                qimage = loadWithDImg(path, &profile);
-            }
-            else
-                // use jpegutils
-            {
-                JPEGUtils::loadJPEGScaled(qimage, path, d->storageSize());
-            }
-
-            failedAtJPEGScaled = qimage.isNull();
+            // Try to extract Exif/IPTC preview first.
+            qimage = loadImagePreview(metadata);
         }
-        else if (ext == QString("PNG")  ||
-                 ext == QString("TIFF") ||
-                 ext == QString("TIF"))
+
+        QFileInfo fileInfo(path);
+        // To speed-up thumb extraction, we now try to load the images by the file extension.
+        QString ext = fileInfo.suffix().toUpper();
+
+        if (qimage.isNull() && !ext.isEmpty())
         {
-            qimage       = loadWithDImg(path, &profile);
-            failedAtDImg = qimage.isNull();
+            if (ext == QString("JPEG") || ext == QString("JPG") || ext == QString("JPE"))
+            {
+                if (colorManage)
+                {
+                    qimage = loadWithDImg(path, &profile);
+                }
+                else
+                    // use jpegutils
+                {
+                    JPEGUtils::loadJPEGScaled(qimage, path, d->storageSize());
+                }
+
+                failedAtJPEGScaled = qimage.isNull();
+            }
+            else if (ext == QString("PNG")  ||
+                     ext == QString("TIFF") ||
+                     ext == QString("TIF"))
+            {
+                qimage       = loadWithDImg(path, &profile);
+                failedAtDImg = qimage.isNull();
+            }
+            else if (ext == QString("PGF"))
+            {
+                // use pgf library to extract reduced version
+                PGFUtils::loadPGFScaled(qimage, path, d->storageSize());
+                failedAtPGFScaled = qimage.isNull();
+            }
         }
-        else if (ext == QString("PGF"))
+
+        // Trying to load with dcraw: RAW files.
+        if (qimage.isNull())
         {
-            // use pgf library to extract reduced version
+            if (KDcraw::loadEmbeddedPreview(qimage, path))
+            {
+                fromEmbeddedPreview = true;
+                profile             = metadata.getIccProfile();
+            }
+        }
+
+        if (qimage.isNull())
+        {
+            //TODO: Use DImg based loader instead?
+            KDcraw::loadHalfPreview(qimage, path);
+        }
+
+        // DImg-dependent loading methods: TIFF, PNG, everything supported by QImage
+        if (qimage.isNull() && !failedAtDImg)
+        {
+            qimage = loadWithDImg(path, &profile);
+        }
+
+        // Try JPEG anyway
+        if (qimage.isNull() && !failedAtJPEGScaled)
+        {
+            // use jpegutils
+            JPEGUtils::loadJPEGScaled(qimage, path, d->storageSize());
+        }
+
+        // Try PGF anyway
+        if (qimage.isNull() && !failedAtPGFScaled)
+        {
+            // use jpegutils
             PGFUtils::loadPGFScaled(qimage, path, d->storageSize());
-            failedAtPGFScaled = qimage.isNull();
         }
     }
 
-    // Trying to load with dcraw: RAW files.
-    if (qimage.isNull())
-    {
-        if (KDcraw::loadEmbeddedPreview(qimage, path))
-        {
-            fromEmbeddedPreview = true;
-            profile             = metadata.getIccProfile();
-        }
-    }
-
-    if (qimage.isNull())
-    {
-        //TODO: Use DImg based loader instead?
-        KDcraw::loadHalfPreview(qimage, path);
-    }
-
-    // DImg-dependent loading methods: TIFF, PNG, everything supported by QImage
-    if (qimage.isNull() && !failedAtDImg)
-    {
-        qimage = loadWithDImg(path, &profile);
-    }
-
-    // Try JPEG anyway
-    if (qimage.isNull() && !failedAtJPEGScaled)
-    {
-        // use jpegutils
-        JPEGUtils::loadJPEGScaled(qimage, path, d->storageSize());
-    }
-
-    // Try PGF anyway
-    if (qimage.isNull() && !failedAtPGFScaled)
-    {
-        // use jpegutils
-        PGFUtils::loadPGFScaled(qimage, path, d->storageSize());
-    }
-
     if (qimage.isNull())
     {
         d->error = i18n("Cannot create thumbnail for %1", path);
@@ -541,7 +543,7 @@ ThumbnailImage ThumbnailCreator::createThumbnail(const ThumbnailInfo& info, cons
         return ThumbnailImage();
     }
 
-    qimage = scaleForStorage(qimage, isFace);
+    qimage = scaleForStorage(qimage);
 
     if (colorManage && !profile.isNull())
     {
@@ -1081,6 +1083,7 @@ void ThumbnailCreator::storeFreedesktop(const ThumbnailInfo& info, const Thumbna
 
             temp.close();
 
+#ifndef Q_OS_WIN
 #if KDE_IS_VERSION(4,2,85)
             // KDE 4.3.0
             ret = KDE::rename(QFile::encodeName(tempFileName),
@@ -1092,6 +1095,9 @@ void ThumbnailCreator::storeFreedesktop(const ThumbnailInfo& info, const Thumbna
 #endif
 
             if (ret != 0)
+#else
+            if(::MoveFileEx(tempFileName.utf16(), thumbPath.utf16(), MOVEFILE_REPLACE_EXISTING | MOVEFILE_WRITE_THROUGH) == 0)
+#endif
             {
                 kDebug() << "Cannot rename thumb file (" << tempFileName << ")";
                 kDebug() << "to (" << thumbPath << ")...";
