@@ -6,7 +6,7 @@
  * Date        : 2008-12-10
  * Description : tool tip widget for iconview, thumbbar, and folderview items
  *
- * Copyright (C) 2008-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -76,7 +76,7 @@ class DIGIKAM_EXPORT DItemToolTip : public QLabel
 
 public:
 
-    explicit DItemToolTip(QWidget* parent = 0);
+    explicit DItemToolTip(QWidget* const parent = 0);
     virtual ~DItemToolTip();
 
 protected:
@@ -94,8 +94,8 @@ protected:
 
 private:
 
-    class DItemToolTipPriv;
-    DItemToolTipPriv* const d;
+    class Private;
+    Private* const d;
 };
 
 }  // namespace Digikam
