@@ -31,7 +31,6 @@
 namespace Digikam
 {
 
-class ModifierPriv;
 class Modifier : public Rule
 {
     Q_OBJECT
@@ -42,8 +41,6 @@ public:
     Modifier(const QString& name, const QString& description, const QString& icon);
     virtual ~Modifier();
 
-    virtual ParseResults& parse(ParseSettings& settings);
-
 protected:
 
     virtual QString parseOperation(ParseSettings& settings) = 0;
@@ -55,11 +52,10 @@ private:
 
 private:
 
-    ModifierPriv* const d;
+    class Private;
+    Private* const d;
 };
 
-typedef QList<Modifier*> ModifierList;
-
 } // namespace Digikam
 
 
