@@ -31,10 +31,10 @@
 
 // KDE includes
 
-#include <kiconloader.h>
 #include <klocale.h>
 #include <kvbox.h>
 #include <kdebug.h>
+#include <kglobal.h>
 
 // LibKDcraw includes
 
@@ -84,7 +84,16 @@ Rotate::Rotate(QObject* parent)
 {
     setToolTitle(i18n("Rotate"));
     setToolDescription(i18n("Rotate images."));
-    setToolIcon(KIcon(SmallIcon("object-rotate-right")));
+    setToolIconName("object-rotate-right");
+}
+
+Rotate::~Rotate()
+{
+    delete d;
+}
+
+void Rotate::registerSettingsWidget()
+{
 
     KVBox* vbox  = new KVBox;
     d->useExif   = new QCheckBox(i18n("Use Exif Orientation"), vbox);
@@ -103,7 +112,7 @@ Rotate::Rotate(QObject* parent)
     QLabel* space = new QLabel(vbox);
     vbox->setStretchFactor(space, 10);
 
-    setSettingsWidget(vbox);
+    m_settingsWidget = vbox;
 
     setNeedResetExifOrientation(true);
 
@@ -117,11 +126,8 @@ Rotate::Rotate(QObject* parent)
             this, SLOT(slotSettingsChanged()));
 
     slotSettingsChanged();
-}
 
-Rotate::~Rotate()
-{
-    delete d;
+    BatchTool::registerSettingsWidget();
 }
 
 BatchToolSettings Rotate::defaultSettings()
@@ -177,9 +183,9 @@ bool Rotate::toolOperations()
 
     // JPEG image : lossless method if non-custom rotation angle.
 
-    if (isJpegImage(inputUrl().toLocalFile()) && image().isNull())
+    if (JPEGUtils::isJpegImage(inputUrl().toLocalFile()) && image().isNull())
     {
-        JpegRotator rotator(inputUrl().toLocalFile());
+        JPEGUtils::JpegRotator rotator(inputUrl().toLocalFile());
         rotator.setDestinationFile(outputUrl().toLocalFile());
 
         if (useExif)
@@ -203,7 +209,7 @@ bool Rotate::toolOperations()
                     break;
 
                 default:
-                    // there is no lossless methode to turn JPEG image with a custom angle.
+                    // there is no lossless method to turn JPEG image with a custom angle.
                     // fall through
                     break;
             }
