@@ -7,7 +7,7 @@
  * Description : a class to manage plugin actions using threads
  *
  * Copyright (C) 2012      by Smit Mehta <smit dot meh at gmail dot com>
- * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -24,27 +24,29 @@
 #ifndef ACTIONTHREAD_H
 #define ACTIONTHREAD_H
 
-// Qt includes
-
 // KDE includes
 
 #include <kurl.h>
+#include <threadweaver/Job.h>
+
+// Libkdcraw includes
+
+#include <libkdcraw/ractionthreadbase.h>
 
 // Local includes
 
-#include "kpactionthreadbase.h"
 #include "settingswidget.h"
 #include "actions.h"
 
-using namespace KIPIPlugins;
 using namespace ThreadWeaver;
+using namespace KDcrawIface;
 
 namespace KIPIDNGConverterPlugin
 {
 
 class ActionData;
 
-class ActionThread : public KPActionThreadBase
+class ActionThread : public RActionThreadBase
 {
     Q_OBJECT
 
@@ -71,43 +73,16 @@ Q_SIGNALS:
     void signalStarting(const KIPIDNGConverterPlugin::ActionData& ad);
     void signalFinished(const KIPIDNGConverterPlugin::ActionData& ad);
 
-public:
+    /** Signal to emit to sub-tasks to cancel processing.
+     */
+    void signalCancelTask();
 
-    class ActionThreadPriv;
 
 private:
 
-    ActionThreadPriv* const d;
+    class Private;
+    Private* const d;
 };
-
-// -----------------------------------------------------------------------------------------------------------------------
-
-class Task : public Job
-{
-    Q_OBJECT
-
-public:
-
-    Task(QObject* const parent, const KUrl& url, const Action& action, ActionThread::ActionThreadPriv* const d);
-    ~Task();
-
-Q_SIGNALS:
-
-    void signalStarting(const KIPIDNGConverterPlugin::ActionData& ad);
-    void signalFinished(const KIPIDNGConverterPlugin::ActionData& ad);
-
-protected:
-
-    void run();
-
-private:
-
-    KUrl                            m_url;
-    Action                          m_action;
-
-    ActionThread::ActionThreadPriv* m_d;
-};
-
 }  // namespace KIPIDNGConverterPlugin
 
 #endif /* ACTIONTHREAD_H */
