@@ -7,9 +7,9 @@
  * @date   2006-09-15
  * @brief  Exiv2 library interface for KDE
  *
- * @author Copyright (C) 2006-2012 by Gilles Caulier
+ * @author Copyright (C) 2006-2014 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2006-2012 by Marcel Wiesweg
+ * @author Copyright (C) 2006-2013 by Marcel Wiesweg
  *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
  *
  * This program is free software; you can redistribute it
@@ -277,6 +277,10 @@ bool KExiv2::loadFromData(const QByteArray& imgData) const
     {
         d->printExiv2ExceptionError("Cannot load metadata using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -329,6 +333,10 @@ bool KExiv2::load(const QString& filePath) const
     {
         d->printExiv2ExceptionError("Cannot load metadata from file ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
 #ifdef _XMP_SUPPORT_
     try
@@ -345,12 +353,8 @@ bool KExiv2::load(const QString& filePath) const
                 xmpsidecar = Exiv2::ImageFactory::open((const char*)QFile::encodeName(xmpSidecarPath));
                 xmpsidecar->readMetadata();
 
-                // Merge sidecar data to main XMP
-                d->mergeXmpData(xmpsidecar->xmpData(), d->xmpMetadata());
-                // Xmp.exif data from the sidecar is available from the exifData of the sidecar image;
-                // but we do not need to care for this, all reading methods check main Exif first,
-                // then Xmp.exif, so we have already implemented the correct reading algorithm.
-
+                // Merge
+                d->loadSidecarData(xmpsidecar);
                 hasLoaded = true;
             }
         }
@@ -359,6 +363,11 @@ bool KExiv2::load(const QString& filePath) const
     {
         d->printExiv2ExceptionError("Cannot load XMP sidecar", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
+
 #endif // _XMP_SUPPORT_
 
     return hasLoaded;
@@ -399,7 +408,7 @@ bool KExiv2::save(const QString& imageFilePath) const
         return false;
     }
 
-    bool writeToFile                     = false; 
+    bool writeToFile                     = false;
     bool writeToSidecar                  = false;
     bool writeToSidecarIfFileNotPossible = false;
     bool writtenToFile                   = false;
