@@ -1,18 +1,24 @@
 /** ===========================================================
  * @file
  *
- * This file was developed as part of the libface project
- * <a href="http://libface.sourceforge.net">http://libface.sourceforge.net</a>
+ * This file is a part of digiKam project
+ * <a href="http://www.digikam.org">http://www.digikam.org</a>
  *
  * @date    2010-01-03
  * @brief   Class to perform faces detection.
+ *          Modesto Castrillón, Oscar Déniz, Daniel Hernández, Javier Lorenzo
+ *          A comparison of face and facial feature detectors based
+ *          on the Viola–Jones general object detection framework
+ *          Machine Vision and Applications, 01/2008
+ *          DOI 10.1007/s00138-010-0250-7
+ *
  * @section DESCRIPTION
  *
  * @author Copyright (C) 2010 by Alex Jironkin
  *         <a href="alexjironkin at gmail dot com">alexjironkin at gmail dot com</a>
  * @author Copyright (C) 2010 by Aditya Bhatt
  *         <a href="adityabhatt at gmail dot com">adityabhatt at gmail dot com</a>
- * @author Copyright (C) 2010-2013 by Gilles Caulier
+ * @author Copyright (C) 2010-2014 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2010-2013 by Marcel Wiesweg
  *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
@@ -36,6 +42,7 @@
 
 // Qt includes
 
+#include <QtCore/QFile>
 #include <QtCore/qmath.h>
 
 // KDE includes
@@ -59,30 +66,70 @@ public:
         minSize         = cv::Size(0,0);
     }
 
-    double searchIncrement;
-    int    grouping;
-    int    flags;
+public:
+
+    double   searchIncrement;
+    int      grouping;
+    int      flags;
     cv::Size minSize;
 };
 
 // --------------------------------------------------------------------------------
 
+static QString findFileInDirs(const QStringList& dirs, const QString& fileName)
+{
+    foreach (const QString &dir, dirs)
+    {
+        const QString file = dir + (dir.endsWith("/") ? "" : "/") + fileName;
+
+        if (QFile::exists(file))
+        {
+            return file;
+        }
+    }
+
+    return QString();
+}
+
+static int distanceOfCenters(const QRect& r1, const QRect& r2)
+{
+    QPointF diff = r1.center() - r2.center();
+    return lround(sqrt(diff.x() * diff.x() + diff.y() * diff.y()));    // Euclidean distance
+}
+
+static QRect toQRect(const cv::Rect& rect)
+{
+    return QRect(rect.x, rect.y, rect.width, rect.height);
+}
+
+static cv::Rect fromQRect(const QRect& rect)
+{
+    return cv::Rect(rect.x(), rect.y(), rect.width(), rect.height());
+}
+
+// --------------------------------------------------------------------------------
+
 class Cascade : public cv::CascadeClassifier
 {
 public:
 
-    Cascade(const QString& dir, const QString& fileName)
+    Cascade(const QStringList& dirs, const QString& fileName)
         : primaryCascade(false),
           verifyingCascade(true)
     {
-        QString file = dir + "/" + fileName;
+        const QString file = findFileInDirs(dirs, fileName);
+
+        if (file.isEmpty())
+        {
+            kDebug() << "failed to locate cascade" << fileName << "in" << dirs;
+            return;
+        }
 
         if (!load(file.toStdString()))
         {
             kDebug() << "failed to load cascade" << file;
             return;
         }
-
     }
 
     cv::Size getOriginalWindowSize() const
@@ -93,18 +140,21 @@ public:
         {
             return oldCascade->orig_window_size;
         }
+
         return cv::Size(0,0);
     }
 
-    /** Assumptions on the relation of the size of a facial feature to the whole face.
-     *  Basically, we say the size is between 1/10 and 1/4, approx 1/6
+    /**
+     * Assumptions on the relation of the size of a facial feature to the whole face.
+     * Basically, we say the size is between 1/10 and 1/4, approx 1/6
      */
     static double faceToFeatureRelationMin()      { return 10; }
     static double faceToFeatureRelationMax()      { return 4;  }
     static double faceToFeatureRelationPresumed() { return 6;  }
 
-    /** A primary cascade does the initial scan on the whole image area
-     *  A verifying cascade scans the area reported by the primary cascade
+    /**
+     * A primary cascade does the initial scan on the whole image area
+     * A verifying cascade scans the area reported by the primary cascade
      */
     void setPrimaryCascade(bool isPrimary = true)
     {
@@ -122,9 +172,10 @@ public:
         return roi.isValid();
     }
 
-    /** given the full face rect (relative to whole image), returns the rectangle
-     *  of the region of interest of this cascade (still relative to whole image).
-     *  For frontal face cascades, returns the given parameter unchanged.
+    /**
+     * given the full face rect (relative to whole image), returns the rectangle
+     * of the region of interest of this cascade (still relative to whole image).
+     * For frontal face cascades, returns the given parameter unchanged.
      */
     cv::Rect faceROI(const CvRect& faceRect) const
     {
@@ -181,8 +232,8 @@ public:
             faceSize.height / faceToFeatureRelationMin() >= getOriginalWindowSize().height)
             return 1.0;
 
-        return max(double(getOriginalWindowSize().width)  * faceToFeatureRelationPresumed() / faceSize.width,
-                   double(getOriginalWindowSize().height) * faceToFeatureRelationPresumed() / faceSize.height);
+        return cv::max(double(getOriginalWindowSize().width)  * faceToFeatureRelationPresumed() / faceSize.width,
+                       double(getOriginalWindowSize().height) * faceToFeatureRelationPresumed() / faceSize.height);
     }
 
     bool lessThanWindowSize(const cv::Size& size) const
@@ -195,9 +246,10 @@ public:
     bool   primaryCascade;
     bool   verifyingCascade;
 
-    /** Facial features have a region of interest, e.g., the left eye is typically
-     *  located in the left upper region of the presumed face.
-     *  For frontal face cascades, this is 0,0 - 1x1. */
+    /**
+     * Facial features have a region of interest, e.g., the left eye is typically
+     * located in the left upper region of the presumed face.
+     * For frontal face cascades, this is 0,0 - 1x1. */
     QRectF roi;
 };
 
@@ -212,11 +264,12 @@ public:
     {
         maxDistance              = 0;
         minDuplicates            = 0;
-
         speedVsAccuracy          = 0.8;
         sensitivityVsSpecificity = 0.8;
     }
 
+public:
+
     QList<Cascade>                 cascades;
 
     int                            maxDistance;    // Maximum distance between two faces to call them unique
@@ -230,37 +283,25 @@ public:
     double                         sensitivityVsSpecificity;
 };
 
-static int distanceOfCenters(const QRect& r1, const QRect& r2)
-{
-    QPointF diff = r1.center() - r2.center();
-    return lround(sqrt(diff.x() * diff.x() + diff.y() * diff.y()));    // Euclidean distance
-}
+// --------------------------------------------------------------------------------
 
-static QRect toQRect(const cv::Rect& rect)
-{
-    return QRect(rect.x, rect.y, rect.width, rect.height);
-}
-
-static cv::Rect fromQRect(const QRect& rect)
-{
-    return cv::Rect(rect.x(), rect.y(), rect.width(), rect.height());
-}
-
-OpenCVFaceDetector::OpenCVFaceDetector(const QString& cascadeDir)
+OpenCVFaceDetector::OpenCVFaceDetector(const QStringList& cascadeDirs)
     : d(new Private)
 {
+    if (cascadeDirs.isEmpty())
+        kError() << "OpenCV Haar Cascade director cannot be found. Did you install OpenCV XML data files?";
 
-    d->cascades << Cascade(cascadeDir, "haarcascade_frontalface_alt.xml");
-    d->cascades << Cascade(cascadeDir, "haarcascade_frontalface_default.xml");
-    d->cascades << Cascade(cascadeDir, "haarcascade_frontalface_alt2.xml");
-    d->cascades << Cascade(cascadeDir, "haarcascade_frontalface_alt_tree.xml");
+    d->cascades << Cascade(cascadeDirs, "haarcascade_frontalface_alt.xml");
+    d->cascades << Cascade(cascadeDirs, "haarcascade_frontalface_default.xml");
+    d->cascades << Cascade(cascadeDirs, "haarcascade_frontalface_alt2.xml");
+    d->cascades << Cascade(cascadeDirs, "haarcascade_frontalface_alt_tree.xml");
 
-    d->cascades << Cascade(cascadeDir, "haarcascade_profileface.xml");
+    d->cascades << Cascade(cascadeDirs, "haarcascade_profileface.xml");
 
-    d->cascades << Cascade(cascadeDir, "haarcascade_mcs_lefteye.xml");
-    d->cascades << Cascade(cascadeDir, "haarcascade_mcs_righteye.xml");
-    d->cascades << Cascade(cascadeDir, "haarcascade_mcs_nose.xml");
-    d->cascades << Cascade(cascadeDir, "haarcascade_mcs_mouth.xml");
+    d->cascades << Cascade(cascadeDirs, "haarcascade_mcs_lefteye.xml");
+    d->cascades << Cascade(cascadeDirs, "haarcascade_mcs_righteye.xml");
+    d->cascades << Cascade(cascadeDirs, "haarcascade_mcs_nose.xml");
+    d->cascades << Cascade(cascadeDirs, "haarcascade_mcs_mouth.xml");
 
     d->cascades[2].setPrimaryCascade();
 
@@ -268,14 +309,6 @@ OpenCVFaceDetector::OpenCVFaceDetector(const QString& cascadeDir)
     d->cascades[6].setROI(0.4, 0,    0.6, 0.6);
     d->cascades[7].setROI(0.2, 0.25, 0.6, 0.6);
     d->cascades[8].setROI(0.1, 0.4,  0.8, 0.6);
-
-    /**
-     * Modesto Castrillón, Oscar Déniz, Daniel Hernández, Javier Lorenzo
-     * A comparison of face and facial feature detectors based
-     * on the Viola–Jones general object detection framework
-     * Machine Vision and Applications, 01/2008
-     * DOI 10.1007/s00138-010-0250-7
-     */
 }
 
 OpenCVFaceDetector::~OpenCVFaceDetector()
@@ -305,7 +338,7 @@ void OpenCVFaceDetector::setSpecificity(double sensitivityVsSpecificity)
 
 void OpenCVFaceDetector::updateParameters(const cv::Size& /*scaledSize*/, const cv::Size& originalSize)
 {
-    double origSize = double(max(originalSize.width, originalSize.height)) / 1000;
+    double origSize = double(cv::max(originalSize.width, originalSize.height)) / 1000;
 
     /* Search increment will determine the number of passes over the image.
      * But with fewer passes, we will miss some faces.
@@ -327,50 +360,59 @@ void OpenCVFaceDetector::updateParameters(const cv::Size& /*scaledSize*/, const
     else
         d->primaryParams.grouping = 3;
 
-    // flag speeds up (very much faster) and potentially lowers sensitivity: We mostly use it,
-    // unless in we want very high sensitivity at low speed
+    /* Flag speeds up (very much faster) and potentially lowers sensitivity: We mostly use it,
+     * unless in we want very high sensitivity at low speed
+     */
     if (d->sensitivityVsSpecificity > 0.1 || d->speedVsAccuracy < 0.9)
         d->primaryParams.flags = CV_HAAR_DO_CANNY_PRUNING;
     else
         d->primaryParams.flags = 0;
 
-    /* greater min size will filter small images, lowering sensitivity, enhancing specificity,
-     * with false positives often small */
+    /* Greater min size will filter small images, lowering sensitivity, enhancing specificity,
+     * with false positives often small
+     */
     double minSize = 32 * d->sensitivityVsSpecificity;
-    /* Original small images deserve a smaller minimum size. */
-    minSize -= 10 * (1.0 - min(1.0, origSize));
+
+    /* Original small images deserve a smaller minimum size
+     */
+    minSize -= 10 * (1.0 - cv::min(1.0, origSize));
 
     /* A small min size means small starting size, together with search increment, determining
-     * the number of operations and thus speed */
+     * the number of operations and thus speed
+     */
     if (d->speedVsAccuracy < 0.75)
         minSize += 100 * (0.75 - d->speedVsAccuracy);
 
-    // Cascade minimum is 20 for most of our cascades (one is 24). Passing 0 will use the cascade minimum.
+    /* Cascade minimum is 20 for most of our cascades (one is 24).
+     * Passing 0 will use the cascade minimum.
+     */
     if (minSize < 20)
         minSize = 0;
+
     d->primaryParams.minSize = cv::Size(lround(minSize), lround(minSize));
 
-    d->maxDistance   = 15;    // Maximum distance between two faces to call them unique
-    d->minDuplicates = 0;
+    d->maxDistance                     = 15;    // Maximum distance between two faces to call them unique
+    d->minDuplicates                   = 0;
 
     d->verifyingParams.searchIncrement = 1.1;
     d->verifyingParams.flags           = 0;
-    // min size is adjusted each time
+
+    // NOTE: min size is adjusted each time
 
 /*
-        kDebug() << "updateParameters: accuracy " << d->speedVsAccuracy
-                 << " sensitivity " << d->sensitivityVsSpecificity
-                 << " - searchIncrement " << d->primaryParams.searchIncrement
-                 << " grouping " << d->primaryParams.grouping
-                 << " flags " << d->primaryParams.flags
-                 << " min size " << d->primaryParams.minSize.width << endl
-                 << " primary cascades: ";
+    kDebug() << "updateParameters: accuracy " << d->speedVsAccuracy
+             << " sensitivity " << d->sensitivityVsSpecificity
+             << " - searchIncrement " << d->primaryParams.searchIncrement
+             << " grouping " << d->primaryParams.grouping
+             << " flags " << d->primaryParams.flags
+             << " min size " << d->primaryParams.minSize.width << endl
+             << " primary cascades: ";
 
-        for (unsigned int i=0; i<d->cascadeProperties.size(); i++)
-            if (d->cascadeProperties[i].primaryCascade)
-                kDebug() << d->cascadeSet->getCascade(i).name << " ";
+    for (unsigned int i=0; i<d->cascadeProperties.size(); i++)
+        if (d->cascadeProperties[i].primaryCascade)
+            kDebug() << d->cascadeSet->getCascade(i).name << " ";
 
-        kDebug() << " maxDistance " << d->maxDistance << " minDuplicates " << d->minDuplicates;
+    kDebug() << " maxDistance " << d->maxDistance << " minDuplicates " << d->minDuplicates;
 */
 
 /*
@@ -392,7 +434,7 @@ void OpenCVFaceDetector::updateParameters(const cv::Size& /*scaledSize*/, const
 
 QList<QRect> OpenCVFaceDetector::cascadeResult(const cv::Mat& inputImage,
                                                Cascade& cascade,
-                                               const DetectObjectParameters& params)
+                                               const DetectObjectParameters& params) const
 {
     // Check whether the cascade has loaded successfully. Else report and error and quit
     if (cascade.empty())
@@ -429,7 +471,7 @@ QList<QRect> OpenCVFaceDetector::cascadeResult(const cv::Mat& inputImage,
     return results;
 }
 
-bool OpenCVFaceDetector::verifyFace(const cv::Mat& inputImage, const QRect& face)
+bool OpenCVFaceDetector::verifyFace(const cv::Mat& inputImage, const QRect& face) const
 {
     // check if we need to verify
     bool hasVerifyingCascade = false;
@@ -449,22 +491,24 @@ bool OpenCVFaceDetector::verifyFace(const cv::Mat& inputImage, const QRect& face
     // Face coordinates. Add a certain margin for the other frontal cascades.
     const cv::Rect faceRect = fromQRect(face);
     const cv::Size faceSize = cv::Size(face.width(), face.height());
-    const int margin        = min(40, max(faceRect.width, faceRect.height));
+    const int margin        = cv::min(40, cv::max(faceRect.width, faceRect.height));
 
     // Clip to bounds of image, after adding the margin
-    cv::Rect extendedRect   = cv::Rect( max(0, faceRect.x - margin),
-                                        max(0, faceRect.y - margin),
-                                        faceRect.width + 2*margin,
-                                        faceRect.height + 2*margin );
-    extendedRect.width      = min(inputImage.cols - extendedRect.x, extendedRect.width);
-    extendedRect.height     = min(inputImage.rows - extendedRect.y, extendedRect.height);
+    cv::Rect extendedRect   = cv::Rect(cv::max(0, faceRect.x - margin),
+                                       cv::max(0, faceRect.y - margin),
+                                               faceRect.width  + 2*margin,
+                                               faceRect.height + 2*margin);
+
+    extendedRect.width      = cv::min(inputImage.cols - extendedRect.x, extendedRect.width);
+    extendedRect.height     = cv::min(inputImage.rows - extendedRect.y, extendedRect.height);
 
 
     // shallow copy by ROI
     cv::Mat extendedFaceImg = inputImage(extendedRect);
 
     QList<QRect> foundFaces;
-    int frontalFaceVotes = 0, facialFeatureVotes = 0;
+    int frontalFaceVotes   = 0;
+    int facialFeatureVotes = 0;
 
     for (int i=0; i<d->cascades.size(); ++i)
     {
@@ -486,7 +530,7 @@ bool OpenCVFaceDetector::verifyFace(const cv::Mat& inputImage, const QRect& face
                 if (!foundFaces.isEmpty())
                     facialFeatureVotes++;
 
-                /*
+/*
                  * This is pretty much working code that scales up the face if it's too small
                  * for the  facial feature cascade. It did not bring me benefit with false positives though.
 
@@ -494,17 +538,20 @@ bool OpenCVFaceDetector::verifyFace(const cv::Mat& inputImage, const QRect& face
                 IplImage* feature = LibFaceUtils::scaledSection(inputImage, roi, factor);
 
                 // kDebug() << "Facial feature in roi " << cascade.roi << "scaled up to" << feature->width << feature->height;
+
                 foundFaces = cascadeResult(feature, cascade.cascade, d->verifyingParams);
 
                 for (vector<Face>::iterator it = foundFaces.begin(); it != foundFaces.end(); ++it)
                 {
-                    cout << "Feature face " << it->getX1() << " " << it->getY1() << " " << it->getWidth() << "x" << it->getHeight() << endl;
+                    kDebug() << "Feature face " << it->getX1() << " " << it->getY1() << " " << it->getWidth() << "x" << it->getHeight();
+
                     double widthScaled = it->getWidth() / factor;
                     double heightScaled = it->getHeight() / factor;
 
-                    / *cout << "Hit feature size " << widthScaled << " " << heightScaled << " "
-                         << (faceSize.width / CascadeProperties::faceToFeatureRelationMin()) << " "
-                         << (faceSize.width / CascadeProperties::faceToFeatureRelationMax()) << endl;* /
+                    // kDebug() << "Hit feature size " << widthScaled << " " << heightScaled << " "
+                    //          << (faceSize.width / CascadeProperties::faceToFeatureRelationMin()) << " "
+                    //          << (faceSize.width / CascadeProperties::faceToFeatureRelationMax());
+
                     if (
                         (widthScaled > faceSize.width / Cascade::faceToFeatureRelationMin()
                          && widthScaled < faceSize.width / Cascade::faceToFeatureRelationMax())
@@ -514,11 +561,11 @@ bool OpenCVFaceDetector::verifyFace(const cv::Mat& inputImage, const QRect& face
                         )
                     {
                         facialFeatureVotes++;
-                        kDebug() << "voting" << endl;
+                        kDebug() << "voting";
                         break;
                     }
                 }
-                */
+*/
             }
             else
             {
@@ -536,6 +583,7 @@ bool OpenCVFaceDetector::verifyFace(const cv::Mat& inputImage, const QRect& face
     }
 
     bool verified;
+
     // Heuristic: Discard a sufficiently large face that shows no facial features
     if (faceSize.width <= 50 && facialFeatureVotes == 0)
     {
@@ -553,13 +601,15 @@ bool OpenCVFaceDetector::verifyFace(const cv::Mat& inputImage, const QRect& face
             verified = false;
     }
 
-    //kDebug() << "Verification finished. Votes: Frontal " << frontalFaceVotes << " Features "
-      //       << facialFeatureVotes << ". Face verified: " << verified;
+/*
+    kDebug() << "Verification finished. Votes: Frontal " << frontalFaceVotes << " Features "
+             << facialFeatureVotes << ". Face verified: " << verified;
+*/
 
     return verified;
 }
 
-QList<QRect> OpenCVFaceDetector::mergeFaces(const cv::Mat& inputImage, const QList< QList<QRect> >& combo)
+QList<QRect> OpenCVFaceDetector::mergeFaces(const cv::Mat& inputImage, const QList< QList<QRect> >& combo) const
 {
     Q_UNUSED(inputImage);
 
@@ -635,7 +685,7 @@ int OpenCVFaceDetector::recommendedImageSizeForDetection()
     return 800;
 }
 
-cv::Mat OpenCVFaceDetector::prepareForDetection(const QImage& inputImage)
+cv::Mat OpenCVFaceDetector::prepareForDetection(const QImage& inputImage) const
 {
     if (inputImage.isNull() || !inputImage.size().isValid())
     {
@@ -650,9 +700,9 @@ cv::Mat OpenCVFaceDetector::prepareForDetection(const QImage& inputImage)
     {
         // Resize to 1024 * 768 (or comparable area for different aspect ratio)
         // Looking for scale factor z where A = w*z * h*z => z = sqrt(A/(w*h))
-        qreal z = qSqrt(qreal(maxAcceptableInputArea) / image.width() / image.height());
+        qreal z          = qSqrt(qreal(maxAcceptableInputArea) / image.width() / image.height());
         QSize scaledSize = image.size() * z;
-        image   = image.scaled(scaledSize);
+        image            = image.scaled(scaledSize);
     }
 
     //TODO: move to common utils, opentldrecognition
@@ -668,7 +718,7 @@ cv::Mat OpenCVFaceDetector::prepareForDetection(const QImage& inputImage)
             cvtColor(cvImageWrapper, cvImage, CV_RGBA2GRAY);
             break;
         default:
-            image = image.convertToFormat(QImage::Format_RGB888);
+            image          = image.convertToFormat(QImage::Format_RGB888);
             cvImageWrapper = cv::Mat(image.height(), image.width(), CV_8UC3, image.scanLine(0), image.bytesPerLine());
             cvtColor(cvImageWrapper, cvImage, CV_RGB2GRAY);
             break;
@@ -682,7 +732,7 @@ QList<QRect> OpenCVFaceDetector::detectFaces(const cv::Mat& inputImage, const cv
 {
     if (inputImage.empty())
     {
-        cout<<"Invalid image given, not detecting faces."<<endl;
+        kDebug() << "Invalid image given, not detecting faces.";
         return QList<QRect>();
     }
 
